<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-compagnon?lang_cible=de
// ** ne pas modifier le fichier **

return [

	// C
	'compagnon_description' => 'Der Begleiter hilft neuen Benutzern bei ihren ersten Schritten im SPIP Redaktionssystem.',
	'compagnon_nom' => 'Begleiter',
	'compagnon_slogan' => 'Assistent für die ersten Schritte mit SPIP',
];
